==> dokuwiki-2012.01.25.tgz: dokuwiki/lib/plugins/plugin/lang/ca/lang.php <==
<?php
/**
 * Catalan language file
 *
 * @author Carles Bellver <carles.bellver@gmail.com>
 * @author carles.bellver@gmail.com
 * @author carles.bellver@cent.uji.es
 * @author Carles Bellver <carles.bellver@cent.uji.es>
 */
$lang['menu']                  = 'Gestió de connectors';
$lang['download']              = 'Baixa i instal·la un nou connector';
$lang['manage']                = 'Connectors instal·lats';
$lang['btn_info']              = 'informació';
$lang['btn_update']            = 'actualitza';
$lang['btn_delete']            = 'suprimeix';
$lang['btn_settings']          = 'paràmetres';
$lang['btn_download']          = 'Baixa';
$lang['btn_enable']            = 'Desa';
$lang['url']                   = 'URL';
$lang['installed']             = 'Instal·lació:';
$lang['lastupdate']            = 'Darrera actualitació:';
$lang['source']                = 'Font:';
$lang['unknown']               = 'desconegut';
$lang['updating']              = 'S\'està actualitzant...';
$lang['updated']               = 'El connector %s s\'ha actualitzat amb èxit.';
$lang['updates']               = 'Els connectors següents s\'han actualitzat amb èxit';
$lang['update_none']           = 'No s\'han trobat actualitzacions.';
$lang['deleting']              = 'S\'està suprimint...';
$lang['deleted']               = 'S\'ha suprimit el connector %s.';
$lang['downloading']           = 'S\'està baixant...';
$lang['downloaded']            = 'El connector %s s\'ha instal·lat amb èxit';
$lang['downloads']             = 'Els connectors següents s\'han instal·lat amb èxit:';
$lang['download_none']         = 'No s\'han trobat connectors, o hi ha hagut un problema desconegut durant el procés de baixada i instal·lació.';
$lang['plugin']                = 'Connector:';
$lang['components']            = 'Components';
$lang['noinfo']                = 'Aquest connector no ha retornat informació. Potser no és vàlid.';
$lang['name']                  = 'Nom:';
$lang['date']                  = 'Data:';
$lang['type']                  = 'Tipus:';
$lang['desc']                  = 'Descripció:';
$lang['author']                = 'Autor:';
$lang['www']                   = 'Web:';
$lang['error']                 = 'S\'ha produït un error desconegut.';
$lang['error_download']        = 'No s\'ha pogut baixar el fitxer del connector: %s';
$lang['error_badurl']          = 'L\'URL no sembla vàlid: no permet determinar el nom del fitxer';
$lang['error_dircreate']       = 'No s\'ha pogut crear una carpeta temporal per rebre la baixada';
$lang['error_decompress']      = 'El gestor de connectors no ha pogut descomprimir el fitxer baixat. Potser no s\'ha baixat correctament, en el qual cas podríeu tornar a intentar-ho. O el format de compressió podria ser desconegut, en el qual cas hauríeu de baixar i instal·lar el connector manualment.';
$lang['error_copy']            = 'S\'ha produït un error de còpia de fitxers quan s\'estaven instal·lant els fitxers del connector <em>%s</em>: potser el disc està ple o els permisos d\'accés són incorrectes. Això pot haver causat una instal·lació incompleta del connector i per tant el vostre wiki pot haver quedat en un estat inestable.';
$lang['error_delete']          = 'S\'ha produït un error quan s\'intentava suprimir el connector <em>%s</em>. La causa més probable d\'això són uns permisos d\'accés insuficients al fitxer o al directori. ';
$lang['enabled']               = 'S\'ha habilitat el connector %s.';
$lang['notenabled']            = 'No s\'ha pogut habilitar el connector %s. Comproveu els permisos dels fitxers.';
$lang['disabled']              = 'S\'ha inhabilitat el connector %s.';
$lang['notdisabled']           = 'No s\'ha pogut inhabilitar el connector %s. Comproveu els permisos dels fitxers.';

==> dokuwiki-2013.05.10.tgz: dokuwiki/lib/plugins/plugin/lang/ca/lang.php <==
<?php
/**
 * Catalan language file
 *
 * @author Carles Bellver <carles.bellver@gmail.com>
 * @author carles.bellver@gmail.com
 * @author carles.bellver@cent.uji.es
 * @author Carles Bellver <carles.bellver@cent.uji.es>
 * @author daniel@6temes.cat
 */
$lang['menu']                  = 'Gestió de connectors';
$lang['download']              = 'Baixa i instal·la un nou connector';
$lang['manage']                = 'Connectors instal·lats';
$lang['btn_info']              = 'informació';
$lang['btn_update']            = 'actualitza';
$lang['btn_delete']            = 'suprimeix';
$lang['btn_settings']          = 'paràmetres';
$lang['btn_download']          = 'Baixa';
$lang['btn_enable']            = 'Desa';
$lang['url']                   = 'URL';
$lang['installed']             = 'Instal·lació:';
$lang['lastupdate']            = 'Darrera actualitació:';
$lang['source']                = 'Font:';
$lang['unknown']               = 'desconegut';
$lang['updating']              = 'S\'està actualitzant...';
$lang['updated']               = 'El connector %s s\'ha actualitzat amb èxit.';
$lang['updates']               = 'Els connectors següents s\'han actualitzat amb èxit';
$lang['update_none']           = 'No s\'han trobat actualitzacions.';
$lang['deleting']              = 'S\'està suprimint...';
$lang['deleted']               = 'S\'ha suprimit el connector %s.';
$lang['downloading']           = 'S\'està baixant...';
$lang['downloaded']            = 'El connector %s s\'ha instal·lat amb èxit';
$lang['downloads']             = 'Els connectors següents s\'han instal·lat amb èxit:';
$lang['download_none']         = 'No s\'han trobat connectors, o hi ha hagut un problema desconegut durant el procés de baixada i instal·lació.';
$lang['plugin']                = 'Connector:';
$lang['components']            = 'Components';
$lang['noinfo']                = 'Aquest connector no ha retornat informació. Potser no és vàlid.';
$lang['name']                  = 'Nom:';
$lang['date']                  = 'Data:';
$lang['type']                  = 'Tipus:';
$lang['desc']                  = 'Descripció:';
$lang['author']                = 'Autor:';
$lang['www']                   = 'Web:';
$lang['error']                 = 'S\'ha produït un error desconegut.';
$lang['error_download']        = 'No s\'ha pogut baixar el fitxer del connector: %s';
$lang['error_badurl']          = 'L\'URL no sembla vàlid: no permet determinar el nom del fitxer';
$lang['error_dircreate']       = 'No s\'ha pogut crear una carpeta temporal per rebre la baixada';
$lang['error_decompress']      = 'El gestor de connectors no ha pogut descomprimir el fitxer baixat. Potser no s\'ha baixat correctament, en el qual cas podríeu tornar a intentar-ho. O el format de compressió podria ser desconegut, en el qual cas hauríeu de baixar i instal·lar el connector manualment.';
$lang['error_copy']            = 'S\'ha produït un error de còpia de fitxers quan s\'estaven instal·lant els fitxers del connector <em>%s</em>: potser el disc està ple o els permisos d\'accés són incorrectes. Això pot haver causat una instal·lació incompleta del connector i per tant el vostre wiki pot haver quedat en un estat inestable.';
$lang['error_delete']          = 'S\'ha produït un error quan s\'intentava suprimir el connector <em>%s</em>. La causa més probable d\'això són uns permisos d\'accés insuficients al fitxer o al directori. ';
$lang['enabled']               = 'S\'ha habilitat el connector %s.';
$lang['notenabled']            = 'No s\'ha pogut habilitar el connector %s. Comproveu els permisos dels fitxers.';
$lang['disabled']              = 'S\'ha inhabilitat el connector %s.';
$lang['notdisabled']           = 'No s\'ha pogut inhabilitar el connector %s. Comproveu els permisos dels fitxers.';
$lang['packageinstalled']      = 'El paquet del connector (%d plugins(s): %s) s\'ha instal·lat correctament.';
